import requests
requests.packages.urllib3.disable_warnings()

def search_for_maps(**kwargs):
    """
    A function used to get JSON user data inside the project.
    """
    if not "maxversion" in kwargs.keys(): kwargs["maxversion"] = "999"
    if not "page" in kwargs.keys(): kwargs["page"] = "0"
    if not "trendsystem" in kwargs.keys(): kwargs["trendsystem"] = "1"
    if not "offset" in kwargs.keys(): kwargs["trendsystem"] = "0"

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/map/public/top/{str(kwargs['gameMode'])}/search?maxversion={str(kwargs['maxversion'])}&result={str(kwargs['result'])}&page={str(kwargs['page'])}&query={str(kwargs['query'])}", verify=False).json()

def find_top_maps(**kwargs):
    """
    A function used to get JSON top map data inside the project.
    """
    if not "maxversion" in kwargs.keys(): kwargs["maxversion"] = "999"
    if not "page" in kwargs.keys(): kwargs["page"] = "0"
    if not "trendsystem" in kwargs.keys(): kwargs["trendsystem"] = "1"
    if not "offset" in kwargs.keys(): kwargs["trendsystem"] = "0"

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/map/public/top/{str(kwargs['gameMode'])}/{str(kwargs['time'])}?maxversion={str(kwargs['maxversion'])}&result={str(kwargs['result'])}&page={str(kwargs['page'])}&trendsystem={str(kwargs['trendsystem'])}&offset={str(kwargs['offset'])}", verify=False).json()

def list_new_maps(**kwargs):
    """
    A function used to get JSON new map data inside the project.
    """
    if not "maxversion" in kwargs.keys(): kwargs["maxversion"] = "999"
    if not "page" in kwargs.keys(): kwargs["page"] = "0"

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/map/public/new/{str(kwargs['gameMode'])}?maxversion={str(kwargs['maxversion'])}&result={str(kwargs['result'])}&page={str(kwargs['page'])}", verify=False).json()

def list_maps_by_user(**kwargs):
    """
    A function used to get JSON user map data inside the project.
    """
    if not "result" in kwargs.keys(): kwargs["result"] = 50
    if not "maxversion" in kwargs.keys(): kwargs["maxversion"] = "999"
    if not "page" in kwargs.keys(): kwargs["page"] = "0"

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/map/public/user/{str(kwargs['userId'])}?maxversion={str(kwargs['maxversion'])}&result={str(kwargs['result'])}&page={str(kwargs['page'])}", verify=False).json()

def list_comments_on_map(**kwargs):
    """
    A function used to get JSON comment data inside the project.
    """
    before = ""
    if "before" in kwargs.keys(): before = f"&before={str(kwargs['before'])}"
    
    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/comment/public/{str(kwargs['mapId'])}?limit={str(kwargs['limit'])}{before}", verify=False).json()

def get_map_details(**kwargs):
    """
    A function used to get JSON map data from it's ID inside the project.
    """
    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/map/public/{str(kwargs['mapId'])}/meta", verify=False).json()

def get_map_thumbnail_url(**kwargs):
    """
    A function used to get thumbnail data inside the project.
    """
    return f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/map/public/{str(kwargs['mapId'])}/thumb"

def search_for_users(**kwargs):
    """
    A function used to get JSON user data inside the project.
    """
    if not "page" in kwargs.keys(): kwargs["page"] = "0"

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/user2/public/search?result={str(kwargs['result'])}&page={str(kwargs['page'])}&query={str(kwargs['query'])}", verify=False).json()

def get_details_for_user(**kwargs):
    """
    A function used to get JSON user data inside the project.
    """

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/user2/public/info/{str(kwargs['userId'])}", verify=False).json()

def list_high_scores_on_map(**kwargs):
    """
    A function used to get JSON highscore data inside the project.
    """

    return requests.get(f"https://tl3.shadowtree-software.se/TL3BackEnd/rest/highscore/public/{str(kwargs['mapId'])}?count={str(kwargs['count'])}", verify=False).json()


import intersection.url.url as url
from intersection import user, map

class Highscore:
    """A class representing an IC map highscore.
    """

    def __init__(self, userId, mapId, score, mapVersion, dateMade, objectId, username):
        self.userId = userId
        self.mapId = mapId, 
        self.score = score
        self.mapVersion = mapVersion
        self.dateMade = dateMade
        self.objectId = objectId
        self.username = username

    def get_author(self):
        return

    def get_map(self):
        return

def list_high_scores_on_map(**kwargs):
    """A function used to used to create a list of `Highscore` objects on a certain map.

    `mapId` - ID of map to get high scores for.

    `count` - Number of high scores to get.

    Usage::

    >>> import intersection
    >>> highscores = intersection.highscore.list_high_scores_on_map(mapId=413915, count=5)
    >>> for highscore in highscores: print(comment.comment)
    """

    data = url.list_high_scores_on_map(**kwargs)
    highscores = []
    for highscoredata in data:
        highscores.append(Highscore(
            highscoredata['userId'],
            highscoredata['mapId'],
            highscoredata['score'],
            highscoredata['mapVersion'],
            highscoredata['dateMade'],
            highscoredata['objectId'],
            highscoredata['username'],
        ))

    return highscores


import intersection.url.url as url
from intersection import map

class User:
    """A class representing an IC user.
    """

    def __init__(self, objectId, gameVersion, lastLogin, maps, name, followers):
        self.objectId = objectId
        self.gameVersion = gameVersion
        self.lastLogin = lastLogin
        self.maps = maps
        self.name = name
        self.followers = followers

    def get_user_maps(self, **kwargs):
        maps = map.list_maps_by_user(userId=self.objectId, **kwargs)
        return maps

def search_for_users(**kwargs):
    """A function used to used to create a list of `User` objects matching a given name.

    `result` - Number of results to return on a page.

    `page` - Index of page of results to return, starting at page 0.

    `query` - Text to search for, looks at the username.

    Usage::

    >>> import intersection
    >>> maps = intersection.user.search_for_user(result=5, query="Feeeeddmmmeee")
    >>> for user in users: print(user.name)
    """

    data = url.search_for_users(**kwargs)
    users = []
    for userdata in data:
        users.append(User(
            userdata['objectId'],
            userdata['gameVersion'],
            userdata['lastLogin'],
            userdata['maps'],
            userdata['name'],
            userdata['followers'],
        ))

    return users

def get_details_for_user(**kwargs):
    """A function used to create a `User` object with a given ID.

    `userId` - ID of user to get info about.

    Usage::

    >>> import intersection
    >>> maps = intersection.user.get_details_for_user(userId=2452411)
    >>> print(user.name)
    """

    data = url.get_details_for_user(**kwargs)
    user = User(
        data['objectId'],
        data['gameVersion'],
        data['lastLogin'],
        data['maps'],
        data['name'],
        data['followers'],
    )

    return user


import intersection.url.url as url
from intersection import user, map

class Comment:
    """A class representing an IC comment.
    """

    def __init__(self, user, map, comment, flag, datePosted, rtl, objectId, username):
        self.user = user
        self.map = map
        self.comment = comment
        self.flag = flag 
        self.datePosted = datePosted
        self.rtl = rtl
        self.objectId = objectId
        self.username = username

    def get_author(self):
        return user.get_details_for_user(userId=self.user)
    
    def get_map(self):
        return map.get_map_details(mapId=self.map)

def list_comments_on_map(**kwargs):
    """A function used to used to create a list of `Comment` objects under a certain map.

    `mapId` - ID of map to list comments for.

    `before` - ID of comment to fetch results after, in order to not get duplicate

    `limit` - Number of comments to return.

    Usage::

    >>> import intersection
    >>> comments = intersection.map.list_maps_by_user(mapId=413915, limit=5)
    >>> for comment in comments: print(comment.comment)
    """

    data = url.list_comments_on_map(**kwargs)
    comments = []
    for commentdata in data:
        comments.append(Comment(
            commentdata['user'],
            commentdata['map'],
            commentdata['comment'],
            commentdata['flag'],
            commentdata['datePosted'],
            commentdata['rtl'],
            commentdata['objectId'],
            commentdata['username'],
        ))

    return comments


from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    "Programming Language :: Python :: 3"
]

setup(
    name="intersection.py",
    version="v2.0.0",
    description="A simple API Wrapper for IC",
    long_description=open("README.md").read(),
    long_description_content_type='text/markdown',
    url='https://github.com/Feeeeddmmmeee/intersection.py',
    author='Feeeeddmmmeee',
    author_email='',
    license='MIT',
    classifiers=classifiers,
    keywords='api',
    packages=find_packages(),
    install_requires=['requests']
)


import intersection

my_user = intersection.user.get_details_for_user(userId=2452411)
print(my_user.name)

my_maps = my_user.get_user_maps()

for map in my_maps:
    print(map.name)

    comment = map.get_comments(limit=1)
    print("Latest comment: " + comment[0].comment)

    if map.gameModeGroup == 2:
        highscore = map.get_highscores(count=1)
        print("Highscore: " + highscore[0].score)


import intersection.url.url as url
from intersection import user, comment, highscore

class Map:
    """A class representing an IC map.
    """

    def __init__(self, name, desc, gameModeGroup, fileName, fileExt, author, created, updated, gameVersion, votesUp, votesDown, highScore, highScoreUser, fullyUploaded, mapVersion, targetScore, favorites, deleted, objectId, authorName):
        self.name = name
        self.desc = desc
        self.gameModeGroup = gameModeGroup
        self.fileName = fileName
        self.fileExt = fileExt
        self.author = author
        self.created = created
        self.updated = updated
        self.gameVersion = gameVersion
        self.votesUp = votesUp
        self.votesDown = votesDown
        self.highScore = highScore
        self.highScoreUser = highScoreUser
        self.fullyUploaded = fullyUploaded
        self.mapVersion = mapVersion
        self.targetScore = targetScore
        self.favorites = favorites
        self.deleted = deleted
        self.objectId = objectId
        self.authorName = authorName

    def get_author(self):
        return user.get_details_for_user(userId=self.objectId)

    def get_highscore_user(self):
        return user.get_details_for_user(userId=self.highScoreUser)
    
    def is_in_trending(self, **kwargs):
        data = find_top_maps(**kwargs)

        for mapdata in data:
            if vars(self) == vars(mapdata):
                return True

        return False

    def get_trending_position(self, **kwargs):
        data = find_top_maps(**kwargs)
        position = 0

        for mapdata in data:
            if vars(self) == vars(mapdata):
                return position
            position = position + 1

    def get_comments(self, **kwargs):
        return comment.list_comments_on_map(mapId=self.objectId, **kwargs)
    
    def get_thumbnail_url(self):
        return get_map_thumbnail_url(mapId=self.objectId)

    def get_highscores(self, **kwargs):
        return highscore.list_high_scores_on_map(mapId=self.objectId, **kwargs)

def search_for_maps(**kwargs):
    """A function used to used to create a list of `Map` objects matching a given name.

    `gameMode` - 1 = Simulation, 2 = Traffic Controller, 3 = Miscellaneous

    `maxversion` - The requester's game version, so if you have version 130 of the app you will not get maps that were made using 140 and might not be possible to play. Setting something very high such as 999 will just search for everything. If not added to the request then only maps made before beta will be searched for.

    `result` - Number of results to return on a page.

    `page` - Index of page of results to return, starting at page 0.

    `query` - Text to search for, will look at author name, map name and map description.

    Usage::

    >>> import intersection
    >>> maps = intersection.map.search_for_maps(gameMode=1, result=5, query="Feeeeddmmmeee")
    >>> for map in maps: print(map.name)
    """
    data = url.search_for_maps(**kwargs)
    maps = []
    for mapdata in data:
        maps.append(Map(
            mapdata['name'], 
            mapdata['desc'], 
            mapdata['gameModeGroup'], 
            mapdata['fileName'], 
            mapdata['fileExt'], 
            mapdata['author'], 
            mapdata['created'], 
            mapdata['updated'], 
            mapdata['gameVersion'], 
            mapdata['votesUp'], 
            mapdata['votesDown'],
            mapdata['highScore'],
            mapdata['highScoreUser'],
            mapdata['fullyUploaded'],
            mapdata['mapVersion'],
            mapdata['targetScore'],
            mapdata['favorites'],
            mapdata['deleted'],
            mapdata['objectId'],
            mapdata['authorName'],
        ))

    return maps

def find_top_maps(**kwargs):
    """A function used to used to create a list of `Map` objects in one of the top categories.

    `gameMode` - 1 = Simulation, 2 = Traffic Controller, 3 = Miscellaneous

    `time` - alltime / month / week / day

    `maxversion` - The requester's game version, so if you have version 130 of the app you will not get maps that were made using 140 and might not be possible to play. Setting something very high such as 999 will just search for everything. If not added to the request then only maps made before beta will be searched for.

    `result` - Number of results to return on a page.

    `page` - Index of page of results to return, starting at page 0.

    `trendsystem` - 0 or 1, should always be set to 1 as that is the current version used ingame.

    `offset` - How many weeks / months / days from today to give results for, negative to go back in time, positive will give future and thus usually an empty list.

    Usage::

    >>> import intersection
    >>> maps = intersection.map.find_top_maps(gameMode=1, time=alltime, result=5)
    >>> for map in maps: print(map.name)
    """

    data = url.find_top_maps(**kwargs)
    maps = []
    for mapdata in data:
        maps.append(Map(
            mapdata['name'], 
            mapdata['desc'], 
            mapdata['gameModeGroup'], 
            mapdata['fileName'], 
            mapdata['fileExt'], 
            mapdata['author'], 
            mapdata['created'], 
            mapdata['updated'], 
            mapdata['gameVersion'], 
            mapdata['votesUp'], 
            mapdata['votesDown'],
            mapdata['highScore'],
            mapdata['highScoreUser'],
            mapdata['fullyUploaded'],
            mapdata['mapVersion'],
            mapdata['targetScore'],
            mapdata['favorites'],
            mapdata['deleted'],
            mapdata['objectId'],
            mapdata['authorName'],
        ))

    return maps

def list_new_maps(**kwargs):
    """A function used to used to create a list of `Map` objects in the new category.

    `gameMode` - 1 = Simulation, 2 = Traffic Controller, 3 = Miscellaneous

    `maxversion` - The requester's game version, so if you have version 130 of the app you will not get maps that were made using 140 and might not be possible to play. Setting something very high such as 999 will just search for everything. If not added to the request then only maps made before beta will be searched for.

    `result` - Number of results to return on a page.

    `page` - Index of page of results to return, starting at page 0.

    Usage::

    >>> import intersection
    >>> maps = intersection.map.list_new_maps(gameMode=1, result=5)
    >>> for map in maps: print(map.name)
    """

    data = url.list_new_maps(**kwargs)
    maps = []
    for mapdata in data:
        maps.append(Map(
            mapdata['name'], 
            mapdata['desc'], 
            mapdata['gameModeGroup'], 
            mapdata['fileName'], 
            mapdata['fileExt'], 
            mapdata['author'], 
            mapdata['created'], 
            mapdata['updated'], 
            mapdata['gameVersion'], 
            mapdata['votesUp'], 
            mapdata['votesDown'],
            mapdata['highScore'],
            mapdata['highScoreUser'],
            mapdata['fullyUploaded'],
            mapdata['mapVersion'],
            mapdata['targetScore'],
            mapdata['favorites'],
            mapdata['deleted'],
            mapdata['objectId'],
            mapdata['authorName'],
        ))

    return maps

def list_maps_by_user(**kwargs):
    """A function used to used to create a list of `Map` objects uploaded by a certain user.

    `userId` - ID of user.

    `maxversion` - The requester's game version, so if you have version 130 of the app you will not get maps that were made using 140 and might not be possible to play. Setting something very high such as 999 will just search for everything. If not added to the request then only maps made before beta will be searched for.

    `result` - Number of results to return on a page.

    `page` - Index of page of results to return, starting at page 0.

    Usage::

    >>> import intersection
    >>> maps = intersection.map.list_maps_by_user(userId=2452411)
    >>> for map in maps: print(map.name)
    """

    data = url.list_maps_by_user(**kwargs)
    maps = []
    for mapdata in data:
        maps.append(Map(
            mapdata['name'], 
            mapdata['desc'], 
            mapdata['gameModeGroup'], 
            mapdata['fileName'], 
            mapdata['fileExt'], 
            mapdata['author'], 
            mapdata['created'], 
            mapdata['updated'], 
            mapdata['gameVersion'], 
            mapdata['votesUp'], 
            mapdata['votesDown'],
            mapdata['highScore'],
            mapdata['highScoreUser'],
            mapdata['fullyUploaded'],
            mapdata['mapVersion'],
            mapdata['targetScore'],
            mapdata['favorites'],
            mapdata['deleted'],
            mapdata['objectId'],
            mapdata['authorName'],
        ))

    return maps

def get_map_details(**kwargs):
    """A function used to used to create a `Map` object from it's ID.

    `mapId` - ID of map to get info about.

    Usage::

    >>> import intersection
    >>> map = intersection.map.get_map_details(mapId=413915)
    >>> print(map.name)
    """
    data = url.get_map_details(**kwargs)
    map = Map(
        data['name'], 
        data['desc'], 
        data['gameModeGroup'], 
        data['fileName'], 
        data['fileExt'], 
        data['author'], 
        data['created'], 
        data['updated'], 
        data['gameVersion'], 
        data['votesUp'], 
        data['votesDown'],
        data['highScore'],
        data['highScoreUser'],
        data['fullyUploaded'],
        data['mapVersion'],
        data['targetScore'],
        data['favorites'],
        data['deleted'],
        data['objectId'],
        data['authorName'],
    )

    return map

def get_map_thumbnail_url(**kwargs):
    """A function used to return a link to a map's thumbnail.

    `mapId` - ID of the map to get an image for.

    Usage::

    >>> import intersection
    >>> link = intersection.map.get_map_thumbnail_url(mapId=413915)
    >>> print(link)
    """

    data = url.get_map_thumbnail_url(**kwargs)
    return data